==> citrus-2.7.4-release.tar.gz: README.md <==
Citrus Integration Testing ![Logo][1]
==============

Welcome to Citrus
---------

Citrus is a test framework written in Java that is able to create
fully automated end-to-end use case tests for enterprise SOA
applications. Citrus simulates surrounding interface partners
supporting a huge set of different transports and protocols like
Http, JMS, TCP/IP, FTP, SOAP, XML and JSON.

Visit our official website at 'http://www.citrusframework.org'
for more information and a detailed documentation.

Preconditions
---------

You need following software on your machine in order to use the
Citrus framework:

* Java 8 or higher
Installed JDK plus JAVA_HOME environment variable set
up and pointing to your Java installation directory

* Java IDE (optional)
A Java IDE will help you to manage your Citrus project (e.g. creating
and executing test cases). You can use the Java IDE that you like best
like Eclipse or IntelliJ IDEA.

* Maven 3.0.x or higher (optional)
Citrus projects will fit best with Maven (http://maven.apache.org).
However it is not required to use Maven. You can also run tests using
ANT (http://ant.apache.org/) for instance.
   
Installation
---------

* Download the latest Citrus release archive

* Extract the archive into an appropriate location on your local storage

* Use the ANT tutorial in our tutorials section to find out how to run
tests using ANT.

* Read the Maven tutorial to find out how to integrate the Citrus tests
into the Maven build lifecycle

Release Notes
---------

Each release comes with a complete reference documentation. At the beginning of
the reference you will find a section about the changes and notes for this release. For detailed 
description of changed packages and classes do also consult the provided javadoc.

Resources
---------

* Citrus's source repository is hosted on github.com. You can clone the
repository with git://github.com/christophd/citrus.git as URL

* Find our blog and more interesting articles around Citrus on
http://labs.consol.de and checkout the various post categories for
selecting a specific topic.

* http://www.citrusframework.org offers tutorials and more information about
Citrus framework.

Samples
---------

Our sample section is still growing. Nevertheless you can find a sample
project called 'FlightBookingService' in our distribution. To build and
run the sample applications go to the 'samples' directory and run 'build.xml'
script with ANT (ant -p).

Licensing
---------
  
Copyright 2006-2018 ConSol Software GmbH.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
  
Consulting
---------

Just in case you need professional support for Citrus have a look at
'http://www.citrusframework.org/docs/consulting/'.
Contact user@citrusframework.org directly for any request or questions
(or use the contact form at 'http://www.consol.com/contact/')

Bugs
---------

Please report any bugs and/or feature requests to dev@citrusframework.org
or directly to http://github.com/christophd/citrus/issues
  
Team
---------

```
ConSol Software GmbH
Christoph Deppisch
christoph.deppisch@consol.de

http://www.citrusframework.org
```

Information
---------

For more information on Citrus see [www.citrusframework.org][2], including
a complete [reference manual][3].

 [1]: http://www.citrusframework.org/img/brand-logo.png "Citrus"
 [2]: http://www.citrusframework.org
 [3]: http://www.citrusframework.org/reference/html/

==> citrus-2.7.8-release.tar.gz: README.md <==
Citrus Integration Testing ![Logo][1]
==============

master: [![Build Status](https://travis-ci.com/citrusframework/citrus.svg?branch=master)](https://travis-ci.org/citrusframework/citrus)  
v2.7-bugfix: [![Build Status](https://travis-ci.com/citrusframework/citrus.svg?branch=v2.7-bugfix)](https://travis-ci.org/citrusframework/citrus)

Welcome to Citrus
---------

Citrus is a test framework written in Java that is able to create
fully automated end-to-end use case tests for enterprise SOA
applications. Citrus simulates surrounding interface partners
supporting a huge set of different transports and protocols like
Http, JMS, TCP/IP, FTP, SOAP, XML and JSON.

Visit our official website at 'http://www.citrusframework.org'
for more information and a detailed documentation.

Preconditions
---------

You need following software on your machine in order to use the
Citrus framework:

* Java 8 or higher
Installed JDK plus JAVA_HOME environment variable set
up and pointing to your Java installation directory

* Java IDE (optional)
A Java IDE will help you to manage your Citrus project (e.g. creating
and executing test cases). You can use the Java IDE that you like best
like Eclipse or IntelliJ IDEA.

* Maven 3.0.x or higher (optional)
Citrus projects will fit best with Maven (http://maven.apache.org).
However it is not required to use Maven. You can also run tests using
ANT (http://ant.apache.org/) for instance.
   
Installation
---------

* Download the latest Citrus release archive

* Extract the archive into an appropriate location on your local storage

* Use the ANT tutorial in our tutorials section to find out how to run
tests using ANT.

* Read the Maven tutorial to find out how to integrate the Citrus tests
into the Maven build lifecycle

Release Notes
---------

Each release comes with a complete reference documentation. At the beginning of
the reference you will find a section about the changes and notes for this release. For detailed 
description of changed packages and classes do also consult the provided javadoc.

Resources
---------

* Citrus's source repository is hosted on github.com. You can clone the
repository with git://github.com/citrusframework/citrus.git as URL

* Find our blog and more interesting articles around Citrus on
http://labs.consol.de and checkout the various post categories for
selecting a specific topic.

* http://www.citrusframework.org offers tutorials and more information about
Citrus framework.

Samples
---------

Our sample section is still growing. Nevertheless you can find a sample
project called 'FlightBookingService' in our distribution. To build and
run the sample applications go to the 'samples' directory and run 'build.xml'
script with ANT (ant -p).

Licensing
---------
  
Copyright 2006-2018 ConSol Software GmbH.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
  
Consulting
---------

Just in case you need professional support for Citrus have a look at
'http://www.citrusframework.org/docs/consulting/'.
Contact user@citrusframework.org directly for any request or questions
(or use the contact form at 'http://www.consol.com/contact/')

Bugs
---------

Please report any bugs and/or feature requests directly to http://github.com/citrusframework/citrus/issues

Information
---------

For more information on Citrus see [www.citrusframework.org][2], including
a complete [reference manual][3].

 [1]: http://www.citrusframework.org/img/brand-logo.png "Citrus"
 [2]: http://www.citrusframework.org
 [3]: http://www.citrusframework.org/reference/html/
